==> tdm_3.0.0.tar.gz: tdm/R/all.Oxtirss.R <==
all.Oxtirss<-function(){
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR input data information--            \n")
     note_for_Theirss_input()
     cat("-----------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     OxtirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),
                            value=c(1,65,167,0,1,300,8,8,5.67))                   
     OxtirSSpar<-edit(OxtirSSpar)                                                                                                                   
##     OxtirSSpar<-ycheck(OxtirSSpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(OxtirSSpar);cat("\n\n")
     Oxtir.ss(OxtirSSpar[9,2],OxtirSSpar[7,2],OxtirSSpar[8,2],OxtirSSpar[6,2],OxtirSSpar[3,2],OxtirSSpar[2,2],OxtirSSpar[5,2],OxtirSSpar[1,2],OxtirSSpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("                -- Output annotations --                   \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------\n")
     ### show(samplesStats("*"))
     X <- read.table("params.csv",header=FALSE)
     cl_F <- X[1,2]
     v_F  <- X[2,2]
     cat("\n") 
     C1<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[8,2])
     Tmax=log(1.85-(cl_F/v_F))/(1.85-(cl_F/v_F))
     C2<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],Tmax)
     ### sim<-matrix(C[1 ,1])
     C3<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[7,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(conc=c("Cmss_obs","** Cmss_pr","** Cpss_pr","** Ctss_pr"),value=c(OxtirSSpar[9,2],C1,C2,C3))
     show(coutput)     
     cat("\n")  
     Oxtir.more()                                     
}

==> tdm_3.0.2.tar.gz: tdm/R/all.Oxtirss.R <==
all.Oxtirss<-function(){
     cat("-----------------------------------------------------------\n")
     cat("    --Oxtriphylline IR input data information--            \n")
     note_for_Theirss_input()
     cat("-----------------------------------------------------------\n")
     cat("\n")
     note_for_close_window()
     OxtirSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),
                            value=c(1,65,167,0,1,300,8,8,5.67))                   
     OxtirSSpar<-edit(OxtirSSpar)                                                                                                                   
##     OxtirSSpar<-ycheck(OxtirSSpar)
     cat("\n")
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(OxtirSSpar);cat("\n\n")
     Oxtir.ss(OxtirSSpar[9,2],OxtirSSpar[7,2],OxtirSSpar[8,2],OxtirSSpar[6,2],OxtirSSpar[3,2],OxtirSSpar[2,2],OxtirSSpar[5,2],OxtirSSpar[1,2],OxtirSSpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     cat("-----------------------------------------------------------\n")
     cat("                -- Output annotations --                   \n")
     note_for_Theirss_output()
     cat("-----------------------------------------------------------\n")
     ### show(samplesStats("*"))
     X <- read.table("params.csv",header=FALSE)
     cl_F <- X[1,2]
     v_F  <- X[2,2]
     cat("\n") 
     C1<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[8,2])
     Tmax=log(1.85/(cl_F/v_F))/(1.85-(cl_F/v_F))
     C2<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],Tmax)
     ### sim<-matrix(C[1 ,1])
     C3<-TheIRsscpr(0.65,OxtirSSpar[6,2],OxtirSSpar[7,2],OxtirSSpar[7,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(conc=c("Cmss_obs","** Cmss_pr","** Cpss_pr","** Ctss_pr"),value=c(OxtirSSpar[9,2],C1,C2,C3))
     show(coutput)     
     cat("\n")  
     Oxtir.more()                                     
}
